"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """


class POWException(Exception):
    """The base AsyncPOW Exception that all other exception classes extend."""

    pass


class POWTimeoutException(POWException):
    """
    Exception raised when a AsyncPOW operation times out.
    """

    pass


class POWConnectionException(POWException):
    """
    Exception raised when a connection error occurs in a AsyncPOW operation.
    """

    pass


class POWAuthException(POWException):
    """
    Exception raised when authentication fails in a AsyncPOW operation.
    """

    pass



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

import asyncio
import json
from typing import Any, Mapping, Optional

from aiohttp import ClientError, ClientSession, hdrs
import backoff
from yarl import URL

from asyncpow.exceptions import POWConnectionException, POWException, POWTimeoutException


@backoff.on_exception(backoff.expo, POWConnectionException, max_tries=5, logger=None)
async def request(
    session: ClientSession,
    url: URL,
    method: str = hdrs.METH_GET,
    request_timeout: int = 10,
    data: Any | None = None,
    json_data: dict[str, Any] | None = None,
    params: Mapping[str, str] | None = None,
    headers: Optional[dict] = None,
) -> Any:
    """Make an HTTP request with backoff and retry logic.


    Args:
        session (ClientSession): The aiohttp ClientSession to use for the request
        url (URL): The URL to sent the request to
        method (str, optional): The HTTP method to use fir the request. Defaults to hdrs.METH_GET.
        request_timeout (int, optional): Timeout for the request in seconds. Defaults to 10.
        data (Any | None, optional): data to include in the request. Defaults to None.
        json_data (dict[str, Any] | None, optional): JSON data to include in the request. Defaults to None.
        params (Mapping[str, str] | None, optional): parameters required for the request. Defaults to None.
        headers (Optional[dict], optional): headers required for the request. Defaults to None.

    Raises:
        POWTimeoutException: Request timeout error
        POWConnectionException: Connection issue error
        POWException: Generic exception

    Returns:
        Any: Response in JSON or text
    """
    if params:
        for key, value in params.items():
            if isinstance(value, bool):
                params[key] = str(value).lower()

    try:
        async with asyncio.timeout(request_timeout):
            response = await session.request(
                method,
                url,
                data=data,
                json=json_data,
                params=params,
                headers=headers,
            )
    except asyncio.TimeoutError as exception:
        msg = "Timeout occurred while connecting to Overseerr instance."
        raise POWTimeoutException(msg) from exception
    except ClientError as exception:
        msg = "Error occurred while communicating with Overseerr."
        raise POWConnectionException(msg) from exception

    content_type = response.headers.get("Content-Type", "")
    if response.status // 100 in [4, 5]:
        contents = await response.read()
        response.close()

        if content_type == "application/json":
            raise POWException(response.status, json.loads(contents.decode("utf8")))
        raise POWException(response.status, {"message": contents.decode("utf8")})

    if "application/json" in content_type:
        return await response.json()

    text = await response.text()
    return {"message": text}



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

from aiohttp import ClientSession
from yarl import URL

from asyncpow.models.search import DiscoverTrendingModel, DiscoverWatchlistModel
from asyncpow.utils.http import request


class Discover:
    """
    Class to interact with discover-related endpoints.

    Initialize the Discover object with the base URL, API key, and session.
    """

    def __init__(self, base_url: URL, api_key: str, session: ClientSession) -> None:
        """Initialize the SearchAPI object with the base URL, API key, and session.

        Args:
            base_url (str): The base URL for the media API.
            api_key (str): The API key for authentication.
            session (ClientSession): HTTP Session

        Returns:
            None
        """
        self.discover_url = base_url.joinpath("discover")
        self.api_key = api_key
        self.session = session

    async def get_trending(self, page: int = 1, lang: str = "en") -> DiscoverTrendingModel:
        """
        Get trending items based on specified page and language.

        Args:
            page (int): The page number for trending items (default is 1).
            lang (str): The language for the trending items (default is "en").

        Returns:
            DiscoverTrendingModel: The model object containing trending items.
        """

        url = self.discover_url.joinpath("trending").with_query({"page": page, "language": lang})
        headers = {"X-Api-Key": self.api_key}
        return await request(self.session, url, headers=headers)

    async def get_watchlist(self, page: int = 1) -> DiscoverWatchlistModel:
        """
        Get the watchlist items based on the specified page.

        Args:
            page (int): The page number for watchlist items (default is 1).

        Returns:
            DiscoverWatchlistModel: The model object containing watchlist items.
        """
        url = self.discover_url.joinpath("watchlist").with_query({"page": page})
        headers = {"X-Api-Key": self.api_key}
        return await request(self.session, url, headers=headers)



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

from dataclasses import dataclass
from typing import List, Optional


@dataclass
class Genre:
    """
    Data class representing a movie genre.
    """

    id: int
    name: str


@dataclass
class Video:
    """
    Data class representing a video.
    """

    url: str
    key: str
    name: str
    size: int
    type: str
    site: str


@dataclass
class ProductionCompany:
    """
    Data class representing a production company.
    """

    id: int
    logoPath: str
    originCountry: str
    name: str


@dataclass
class ProductionCountry:
    """
    Data class representing a production country.
    """

    iso_3166_1: str
    name: str


@dataclass
class ReleaseDate:
    """
    Data class representing a release date.
    """

    certification: str
    iso_639_1: str
    note: str
    release_date: str
    type: int


@dataclass
class Cast:
    """
    Data class representing a cast member.
    """

    id: int
    castId: int
    character: str
    creditId: str
    gender: int
    name: str
    order: int
    profilePath: str


@dataclass
class Crew:
    """
    Data class representing a crew member.
    """

    id: int
    creditId: str
    gender: int
    name: str
    job: str
    department: str
    profilePath: str


@dataclass
class Collection:
    """
    Data class representing a collection.
    """

    id: int
    name: str
    posterPath: str
    backdropPath: str


@dataclass
class ExternalIds:
    """
    Data class representing external IDs.
    """

    facebookId: str
    freebaseId: str
    freebaseMid: str
    imdbId: str
    instagramId: str
    tvdbId: int
    tvrageId: int
    twitterId: str


@dataclass
class RequestedBy:
    """
    Data class representing the user who made the request.
    """

    id: int
    email: str
    username: str
    plexToken: str
    plexUsername: str
    userType: int
    permissions: int
    avatar: str
    createdAt: str
    updatedAt: str
    requestCount: int


@dataclass
class ModifiedBy:
    """
    Data class representing the user who modified the item.
    """

    id: int
    email: str
    username: str
    plexToken: str
    plexUsername: str
    userType: int
    permissions: int
    avatar: str
    createdAt: str
    updatedAt: str
    requestCount: int


@dataclass
class Request:
    """
    Data class representing a request.
    """

    id: int
    status: int
    media: str
    createdAt: str
    updatedAt: str
    requestedBy: RequestedBy
    modifiedBy: ModifiedBy
    is4k: bool
    serverId: int
    profileId: int
    rootFolder: str


@dataclass
class MediaInfo:
    """
    Data class representing media information.
    """

    id: int
    tmdbId: int
    tvdbId: int
    status: int
    requests: List[Request]
    createdAt: str
    updatedAt: str


@dataclass
class BuyFlatrate:
    """
    Data class representing a flatrate purchase option.
    """

    displayPriority: int
    logoPath: str
    id: int
    name: str


@dataclass
class WatchProvider:
    """
    Data class representing a watch provider.
    """

    iso_3166_1: str
    link: str
    buy: List[BuyFlatrate]
    flatrate: List[BuyFlatrate]


@dataclass
class MovieModel:
    """
    Data class representing a movie model.
    """

    id: int
    imdbId: str
    adult: bool
    backdropPath: str
    posterPath: str
    budget: int
    genres: List[Genre]
    homepage: str
    relatedVideos: List[Video]
    originalLanguage: str
    originalTitle: str
    overview: str
    popularity: float
    productionCompanies: List[ProductionCompany]
    productionCountries: List[ProductionCountry]
    releaseDate: str
    releases: dict
    revenue: int
    runtime: int
    spokenLanguages: List[str]
    status: str
    tagline: str
    title: str
    video: bool
    voteAverage: float
    voteCount: int
    credits: dict
    collection: Optional[Collection]
    externalIds: ExternalIds
    mediaInfo: MediaInfo
    watchProviders: List[List[WatchProvider]]



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

from dataclasses import dataclass

from asyncpow.models.media import MediaInfoModel


@dataclass
class MovieResultModel:
    """
    Data class representing a movie search result.
    """

    id: int
    mediaType: str
    popularity: int
    posterPath: str
    backdropPath: str
    voteCount: int
    voteAverage: int
    genreIds: list[int]
    overview: str
    originalLanguage: str
    title: str
    originalTitle: str
    releaseDate: str
    adult: bool
    video: bool
    mediaInfo: MediaInfoModel


@dataclass
class TvResultModel:
    """
    Data class representing a TV show search result.
    """

    id: int
    mediaType: str
    popularity: int
    posterPath: str
    backdropPath: str
    voteCount: int
    voteAverage: int
    genreIds: list[int]
    overview: str
    originalLanguage: str
    name: str
    originalName: str
    originCountry: list[str]
    firstAirDate: str
    mediaInfo: MediaInfoModel


@dataclass
class PersonResultModel:
    """
    Data class representing a person search result.
    """

    id: int
    profilePath: str
    adult: bool
    mediaType: str
    knwonFor: list[MovieResultModel | TvResultModel]


@dataclass
class DiscoverTrendingModel:
    """
    Data class representing trending items in discovery.
    """

    page: int
    totalPages: int
    totalResults: int
    results: list[MovieResultModel | TvResultModel | PersonResultModel]


@dataclass
class WatchlistModel:
    """
    Data class representing an item in the watchlist.
    """

    ratingKey: str
    title: str
    mediaType: str
    tmdbId: int


@dataclass
class DiscoverWatchlistModel:
    """
    Data class representing watchlist items in discovery.
    """

    page: int
    totalPages: int
    totalResults: int
    results: list[WatchlistModel]



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

import aiohttp
from cachetools import TTLCache
from yarl import URL

from asyncpow.apis.media import Media
from asyncpow.apis.search import Discover
from asyncpow.apis.status import Status
from asyncpow.const import API_URI

VERSION_CACHE: TTLCache[str, str | None] = TTLCache(maxsize=16, ttl=7200)


class Overseerr:
    """The Overseerr class provides convenient access to Overseerr's API.

    Instances of this class are the gateway to interacting with Overseerr's API through
    AsyncPOW. The canonical way to obtain an instance of this class is via:

    .. code-block:: python

        from asyncpow import overseerr

        async with Overseerr(
            host="OVERSEERR_HOST",
            api_key="OVERSEER_KEY",
            port="5055",
            ssl=True,
            base_url="overseerr/",
        ) as api:
            # Inside the context, you can use the API wrapper as needed
            status = await api.status.get_status()
            print("Status:", status)

    """

    def __init__(
        self,
        host: str,
        api_key: str,
        port: int | None = None,
        tls: bool = True,
        base_path: str = "",
    ):
        """
        Initialize the Overseerr API client with the host, API key, and optional port, SSL, and base URL.

        Args:
            host (str): The host of the Overseerr instance.
            api_key (str): The API key for authentication.
            port (int, Optional): The port of the Overseerr instance (default is None).
            tls (bool): Flag indicating whether SSL is enabled (default is True).
            base_path (str): The base URL for the API (default is "").

        Returns:
            None
        """
        scheme = "https" if tls else "http"
        self.url = URL.build(
            scheme=scheme,
            host=host,
            port=port,
            path=base_path,
        ).joinpath(API_URI)
        self.api_key = api_key

        # Initialize a single instance of ClientSession
        self._session = aiohttp.ClientSession()

        # Initialize instances of API classes
        self.status = Status(self.url, self.api_key, self._session)
        self.discover = Discover(self.url, self.api_key, self._session)
        self.media = Media(self.url, self.api_key, self._session)

    async def __aenter__(self):
        """
        Enter method for asynchronous context manager.

        Returns:
            self
        """
        return self

    async def __aexit__(self, exc_type, exc, tb):
        """
        Exit method for asynchronous context manager.

        Args:
            exc_type: The exception type.
            exc: The exception instance.
            tb: The traceback.

        Returns:
            None

        Raises:
            Any exceptions raised during the session close operation.
        """

        # Close the session when exiting the context manager
        await self._session.close()



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

from aiohttp import ClientSession
from yarl import URL

from asyncpow.models.status import StatusAppDataModel, StatusModel
from asyncpow.utils.http import request


class Status:
    """
    Class to interact with status-related endpoints.

    Initialize the Status object with the base URL, API key, and session.
    """

    def __init__(self, base_url: URL, api_key: str, session: ClientSession) -> None:
        """
        Initialize the Status object with the base URL, API key, and session.

        Returns:
            None
        """

        self.base_url = base_url.joinpath("status")
        self.api_key = api_key
        self.session = session

    async def get_status(self) -> StatusModel:
        """
        Get the status information.

        Returns:
            StatusModel: The model object representing the status information.
        """

        return await request(self.session, self.base_url)

    async def get_appdata(self) -> StatusAppDataModel:
        """
        Get the application data.

        Returns:
            StatusAppDataModel: The model object representing the application data.
        """

        url = self.base_url.joinpath("appdata")
        return await request(self.session, url)



"""
 AsyncPOW - https://github.com/totaldebug/asyncpow

 Copyright (c) 2024 Steven Marks, Total Debug

 Permission is hereby granted, free of charge, to any person obtaining a copy of
 this software and associated documentation files (the "Software"), to deal in
 the Software without restriction, including without limitation the rights to
 use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of
 the Software, and to permit persons to whom the Software is furnished to do so,
 subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all
 copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
 COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
 IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 """

from dataclasses import dataclass
from enum import Enum

from asyncpow.models.common import PageInfoModel, UserModel


class MediaFilterOptions(Enum):
    """
    Enum class for media filter options.
    """

    ALL = "all"
    AVAILABLE = "available"
    PARTIAL = "partial"
    ALLAVAILABLE = "allavailable"
    PENDING = "pending"
    PROCESSING = "processing"


class MediaStatusOptions(Enum):
    """
    Enum class representing media status options.
    """

    AVAILABLE = "available"
    PARTIAL = "partial"
    PENDING = "pending"
    PROCESSING = "processing"
    UNKNOWN = "unknown"


@dataclass
class MediaRequestModel:
    """
    Data class representing a media request model.
    """

    id: int
    status: int
    media: dict
    createdAt: str
    updatedAt: str
    requestedBy: UserModel
    modifiedBy: list[UserModel]
    is4k: bool
    serverId: int
    profileId: int
    rootFolder: str


@dataclass
class MediaInfoModel:
    """
    Data class representing media information model.
    """

    id: int
    tmdbId: int
    tvdbId: int
    status: int
    requests: MediaRequestModel
    createdAt: str
    updatedAt: str


@dataclass
class MediaModel:
    """
    Data class representing a media model.
    """

    pageInfo: PageInfoModel
    results: MediaInfoModel


@dataclass
class MediaModel2:
    """
    Data class representing a secondary media model.
    """

    id: int
    tmdbId: int
    tvdbId: int
    status: int
    requests: list[MediaInfoModel]
